#
# CGAL
#

set(proj CGAL)
set(proj_DEPENDENCIES ${${proj}_DEPENDENCIES})
set(proj_VERSION ${${proj}_VERSION})
string(TOUPPER ${proj} proj_UPPER)

# Sanity checks
if(DEFINED ${proj_UPPER}_DIR AND NOT EXISTS ${${proj_UPPER}_DIR})
  message(FATAL_ERROR "${proj_UPPER}_DIR variable is defined but corresponds to non-existing directory.")
endif()

if (FEniCS_BUILD_${proj} AND NOT DEFINED ${proj_UPPER}_DIR)
  if ("${proj_VERSION}" VERSION_EQUAL "3.6.1")
    set(proj_URL "https://gforge.inria.fr/frs/download.php/27222/CGAL-3.6.1.tar.gz")
    set(proj_URL_MD5 "c84e11327bbdd8d83e2abd17c5293b5b")
    set(proj_EXTRACTSTO "CGAL-3.6.1")
  elseif ("${proj_VERSION}" VERSION_EQUAL "3.8")
    set(proj_URL "https://gforge.inria.fr/frs/download.php/28500/CGAL-3.8.tar.gz")
    set(proj_URL_MD5 "b8a79e62e4d8ba8b649d815aebbd1c0a")
    set(proj_EXTRACTSTO "CGAL-3.8")
  elseif ("${proj_VERSION}" VERSION_EQUAL "3.9")
    set(proj_URL "https://gforge.inria.fr/frs/download.php/29125/CGAL-3.9.tar.gz")
    set(proj_URL_MD5 "797697130ff9231627521c0a38f16d2f")
    set(proj_EXTRACTSTO "CGAL-3.9")
  elseif ("${proj_VERSION}" VERSION_EQUAL "4.0")
    set(proj_URL "https://gforge.inria.fr/frs/download.php/30387/CGAL-4.0.tar.gz")
    set(proj_URL_MD5 "5e0c11a3f3628f58c5948d6d10271f0c")
    set(proj_EXTRACTSTO "CGAL-4.0")
  else()
    set(proj_URL "https://gforge.inria.fr/frs/download.php/31175/CGAL-4.0.2.tar.gz")
    set(proj_URL_MD5 "d0d1577f72fc8ab49fed3d966dae19da")
    set(proj_EXTRACTSTO "CGAL-4.0.2")
  endif()

  # Use local copy if it exists
  get_filename_component(proj_TARBALL "${proj_URL}" NAME)
  if (EXISTS "${FEniCS_SOURCE_DIR}/src/${proj_TARBALL}")
    set(proj_URL "${FEniCS_SOURCE_DIR}/src/${proj_TARBALL}")
  endif()

  # We run a cmake -P script to download and extract this external project
  configure_file(
    ${CMAKE_CURRENT_SOURCE_DIR}/templates/ep_download_step.cmake.in
    ${CMAKE_CURRENT_BINARY_DIR}/${proj}_download_step.cmake @ONLY)

  set(ep_patch_command "")
  if (APPLE AND "${proj_VERSION}" VERSION_EQUAL "3.6.1")
    set(ep_patch_command
      ${PATCH_EXECUTABLE} -p0 --forward --batch < ${CMAKE_CURRENT_SOURCE_DIR}/patches/cgal.patch
      )
  endif()

  externalproject_add(${proj}
    DEPENDS ${proj_DEPENDENCIES}
    DOWNLOAD_COMMAND ${CMAKE_COMMAND} -P ${CMAKE_CURRENT_BINARY_DIR}/${proj}_download_step.cmake
    PATCH_COMMAND ${ep_patch_command}
    CMAKE_GENERATOR ${CMAKE_GENERATOR}
    CMAKE_ARGS
      ${ep_common_args}
      #-D CMAKE_CXX_FLAGS:STRING=${CMAKE_CXX_FLAGS}
      -D CMAKE_VERBOSE_MAKEFILE:BOOL=OFF
      -D LIB_INSTALL_DIR:STRING=lib
      -D CGAL_INSTALL_LIB_DIR:STRING=lib
      -D WITH_CGAL_Core:BOOL=OFF
      -D WITH_CGAL_ImageIO:BOOL=OFF
      -D WITH_CGAL_Qt3:BOOL=OFF
      -D WITH_CGAL_Qt4:BOOL=OFF
      -D WITH_GMP:BOOL=OFF
      -D CGAL_SOURCE_INSTALL:BOOL=OFF
      ${Boost_CMAKE_ARGS}
    )

  set(${proj_UPPER}_DIR ${ep_install_dir})
else()
    fenicsmacro_empty_externalproject(${proj} "${proj_DEPENDENCIES}")
endif()
