#
# DOLFIN
#

set(proj DOLFIN)
set(proj_DEPENDENCIES ${${proj}_DEPENDENCIES})
set(proj_VERSION ${${proj}_VERSION})

if (FEniCS_BUILD_${proj})
  if (FEniCS_BUILD_STABLE)
    set(proj_URL "http://launchpad.net/dolfin/1.0.x/${proj_VERSION}/+download/dolfin-${proj_VERSION}.tar.gz")
    set(proj_URL_MD5_0.9.9 "57a892f9668abd5ee79c645475422c6a")
    set(proj_URL_MD5_0.9.10 "7224edfa449737821e37f0411709df30")
    set(proj_URL_MD5_0.9.11 "62ae018537fef6b7329de5e7bb2f3588")
    set(proj_URL_MD5_1.0-beta "bded9c6eaea8ff7832ac9f76ff946eda")
    set(proj_URL_MD5_1.0-beta2 "bfda7c13dab57c1badfb35e8f0942663")
    set(proj_URL_MD5_1.0-rc1 "4da3699a5481c944bb87675c06c82667")
    set(proj_URL_MD5_1.0-rc2 "da0b04ad9ecac170f2c48186b7f37792")
    set(proj_URL_MD5_1.0.0 "f2d27de414c2e1768a03464bb38fef38")
    set(proj_URL_MD5 "${proj_URL_MD5_${proj_VERSION}}")
  else()
    set(proj_URL "http://www.fenicsproject.org/pub/software/dolfin/dolfin-snapshot.tar.gz")
    set(proj_URL_MD5 "")
  endif()

  set(proj_PATCH_COMMAND "")
  if ("${proj_VERSION}" STREQUAL "1.0-beta")
    set(proj_PATCH_COMMAND
      ${PATCH_EXECUTABLE} -p1 --forward --batch < ${CMAKE_CURRENT_SOURCE_DIR}/patches/dolfin-1.0-beta.patch)
  elseif ("${proj_VERSION}" VERSION_EQUAL "0.9.9")
    set(proj_PATCH_COMMAND
      ${PATCH_EXECUTABLE} -p1 --forward --batch < ${CMAKE_CURRENT_SOURCE_DIR}/patches/dolfin-0.9.9.patch)
  endif()

  if (NOT ${FEniCS_FORCE_REBUILD})
    # Use local copy if it exists
    get_filename_component(proj_TARBALL "${proj_URL}" NAME)
    if (EXISTS "${FEniCS_SOURCE_DIR}/src/${proj_TARBALL}")
      set(proj_URL "${FEniCS_SOURCE_DIR}/src/${proj_TARBALL}")
    endif()
  endif()

  set(DOLFIN_Armadillo_args)
  if (DEFINED ARMADILLO_DIR)
    set(DOLFIN_Armadillo_args
      -D ARMADILLO_DIR:PATH=${ARMADILLO_DIR})
  endif()

  set(DOLFIN_CGAL_args)
  if (DEFINED CGAL_DIR)
    set(DOLFIN_CGAL_args
      -D CGAL_DIR:PATH=${CGAL_DIR})
  endif()

  set(DOLFIN_LAPACK_args)
  if (DEFINED ATLAS_DIR)
    # FIXME: Not tested on Windows
    set(DOLFIN_LAPACK_args
      -D BLA_VENDOR:STRING=ATLAS
      -D LAPACK_DIR:PATH=${ATLAS_DIR}
      -D BLAS_DIR:PATH=${ATLAS_DIR}
      -D LAPACK_LIBRARIES:FILEPATH=${ATLAS_DIR}/lib/liblapack.a
      -D BLAS_LIBRARIES:FILEPATH=${ATLAS_DIR}/lib/libatlas.a
      )
  elseif (DEFINED LAPACK_DIR)
    set(DOLFIN_LAPACK_args
      -D LAPACK_DIR:PATH=${LAPACK_DIR}
      -D BLAS_DIR:PATH=${LAPACK_DIR}
      )
  endif()

  set(DOLFIN_SuiteSparse_args)
  if (DEFINED SUITESPARSE_DIR)
    set(DOLFIN_SuiteSparse_args 
      -D AMD_DIR:PATH=${SUITESPARSE_DIR}
      -D CAMD_DIR:PATH=${SUITESPARSE_DIR}
      -D COLAMD_DIR:PATH=${SUITESPARSE_DIR}
      -D CCOLAMD_DIR:PATH=${SUITESPARSE_DIR}
      -D CHOLMOD_DIR:PATH=${SUITESPARSE_DIR}
      -D UMFPACK_DIR:PATH=${SUITESPARSE_DIR})
  endif()

  set(DOLFIN_PETSc_args)
  if (DEFINED PETSC_DIR)
    set(DOLFIN_PETSc_args
      -D PETSC_DIR:PATH=${PETSC_DIR})
  endif()

  set(DOLFIN_SLEPc_args)
  if (DEFINED SLEPC_DIR)
    set(DOLFIN_SLEPc_args
      -D SLEPC_DIR:PATH=${SLEPC_DIR})
  endif()

  set(DOLFIN_MTL4_args)
  if (DEFINED MTL4_DIR)
    set(DOLFIN_MTL4_args
      -D MTL4_DIR:PATH=${MTL4_DIR})
  endif()

  set(DOLFIN_zlib_args)
  if (DEFINED ZLIB_DIR)
    set(DOLFIN_zlib_args
      -D ZLIB_INCLUDE_DIRS:FILEPATH=${ZLIB_INCLUDE_DIRS}
      -D ZLIB_LIBRARY:FILEPATH=${ZLIB_LIBRARY})
  endif()

  externalproject_add(${proj}
    DEPENDS ${proj_DEPENDENCIES}
    URL ${proj_URL}
    URL_MD5 ${proj_URL_MD5}
    DOWNLOAD_DIR ${ep_download_dir}
    PATCH_COMMAND ${proj_PATCH_COMMAND}
    CMAKE_GENERATOR ${CMAKE_GENERATOR}
    CMAKE_ARGS
      ${ep_common_args}
      #-D CMAKE_CXX_FLAGS:STRING=${CMAKE_CXX_FLAGS}
      -D CMAKE_VERBOSE_MAKEFILE:BOOL=OFF
      -D DOLFIN_ENABLE_UNIT_TESTS:BOOL=OFF
      -D CMAKE_SKIP_RPATH:BOOL=ON
      -D CMAKE_INSTALL_RPATH_USE_LINK_PATH:BOOL=OFF
      -D SWIG_EXECUTABLE:FILEPATH=${SWIG_EXECUTABLE}
      ${DOLFIN_Armadillo_args}
      ${DOLFIN_LAPACK_args}
      ${DOLFIN_SuiteSparse_args}
      ${DOLFIN_PETSc_args}
      ${DOLFIN_SLEPc_args}
      ${DOLFIN_MTL4_args}
      ${DOLFIN_zlib_args}
      ${Boost_CMAKE_ARGS}
    )

  if (FEniCS_FORCE_REBUILD)
    externalproject_add_step(${proj} force_rebuild
      COMMENT "Force ${proj} re-build"
      DEPENDERS download
      ALWAYS 1
      WORKING_DIRECTORY ${ep_source_dir}/${proj}-build
      )
  endif()
else()
  fenicsmacro_empty_externalproject(${proj} "${proj_DEPENDENCIES}")
endif()
